<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * This partial template renders the settings page for the Model configuration
 * in the WordPress admin area. It displays the plugin header, logo, and the
 * settings form for configuring custom LLM provider options.
 *
 * @package    ai-tool-center
 * @subpackage Aitoce/admin/model-display
 * @author     sjvision <contact@ai-tool-center.com>
 */

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly for security

// phpcs:disable PluginCheck.CodeAnalysis.ImageFunctions.NonEnqueuedImage

// Display any admin settings errors or notifications
settings_errors();

?>

<!--
    This file is primarily HTML with some PHP for dynamic content.
    It renders the plugin header, logo, and the settings form for the Model page.
-->

<div class="wrap">
    <div class="aitoce-wrapper">
        <!-- Plugin header with logo -->
        <div id="aitoce-icon"><img src="<?php echo esc_url(plugins_url('images/knot.png', __DIR__)); ?>"
                alt="<?php esc_attr_e('AI Tool Center Icon', 'ai-tool-center'); ?>" style="vertical-align: middle;"
                width="35" height="35" />
        </div>
        <h1 class="aitoce-admin-header">
            <?php esc_html_e('AI Tool Center', 'ai-tool-center'); ?>
            <img src="<?php echo esc_url(plugins_url('images/nimbot-head-left.png', __DIR__)); ?>"
                alt="<?php esc_attr_e('Nimbot Head', 'ai-tool-center'); ?>"
                style="vertical-align: middle; margin-left: 10px; margin-bottom: 10px;" width="46" height="37" />
        </h1>
        <div id="tabs">
            <ul>
                <li><a href="#aitoce-model-set">OpenAI</a></li>
                <li><a href="#aitoce-model-custom">Custom</a></li>
            </ul>

            <div id="aitoce-model-set">
                <!-- Settings form for the Model options -->
                <form id="aitoce-account-form" class="aitoce-admin-form" method="post" action="options.php">
                    <?php
                    // Output security fields for the registered setting
                    settings_fields(AITOCE_OPTION_SLUG_MODEL_OPENAI);
                    // Output all settings sections and fields for this page
                    do_settings_sections(AITOCE_OPTION_SLUG_MODEL_OPENAI);
                    // Output the submit button
                    submit_button();
                    ?>
                    <div id="aitoce-version"><?php echo 'v' . esc_html(AITOCE_VERSION); ?></div>
                </form>
            </div>

            <div id="aitoce-model-custom">
                <!-- Settings form for the Model options -->
                <form id="aitoce-account-form" class="aitoce-admin-form" method="post" action="options.php">
                    <?php
                    // Output security fields for the registered setting
                    settings_fields(AITOCE_OPTION_SLUG_MODEL_CUSTOM);
                    // Output all settings sections and fields for this page
                    do_settings_sections(AITOCE_OPTION_SLUG_MODEL_CUSTOM);
                    // Output the submit button
                    submit_button();
                    ?>
                    <div id="aitoce-version"><?php echo 'v' . esc_html(AITOCE_VERSION); ?></div>
                </form>
            </div>
        </div>
    </div>
</div>