<?php
/**
 * The shortcodes functionality of the plugin.
 *
 * This class defines and registers shortcodes for displaying the NimBot chatbot
 * on the public-facing side of the WordPress site. It also provides examples for
 * enqueuing the necessary styles and scripts for the chatbot interface.
 *
 * @package         ai-tool-center
 * @subpackage      Aitoce/includes
 * @author          sjvision <contact@ai-tool-center.com>
 */
class Aitoce_Shortcodes
{
    /**
     * Register the nimbot display on page shortcode for the public-facing side of the site.
     *
     * Usage: [nimbot-page] to show the chatbot on any page or widget.
     * Outputs the HTML structure for the NimBot chat interface, including header,
     * messages area, and input controls.
     * 
     * @since   1.0.0
     * @return  bool|string The buffered HTML for the chatbot, or false on failure.
     */
    public function aitoce_nimbot_page_shortcode(): bool|string
    {
        ob_start();
        ?>
        <div id="aitoce-page-container" class="aitoce-page-container draggable">
            <div id="aitoce-page-chat-box" class="aitoce-page-chat-box">
                <div id="aitoce-chat-header" class="aitoce-chat-header">
                    <div id="aitoce-chat-header-text" class="aitoce-chat-header-text">
                        <?php esc_html_e('NimBot', 'ai-tool-center'); ?></div>
                    <i id="aitoce-page-refresh-chat" class="fa-solid fa-arrows-rotate" title="Reset"></i>
                </div>
                <div id="aitoce-page-messages" class="aitoce-page-chat-messages"></div>
                <div id="aitoce-chat-input-area" class="aitoce-chat-input-area">
                    <textarea id="aitoce-page-input" class="aitoce-chat-input" rows="3"
                        placeholder="<?php esc_html_e('Type a message...', 'ai-tool-center'); ?>"></textarea>
                    <button id="aitoce-page-send-btn"
                        class="aitoce-send-btn"><?php esc_html_e('Send', 'ai-tool-center'); ?></button>
                </div>
            </div>
        </div>
        <?php
        return ob_get_clean();
    }
}
