<?php

/**
 * Defines all constants used throughout the AI Tool Center plugin.
 *
 * This file sets up constant values for option names, section names, menu slugs,
 * and other identifiers used in the plugin's admin pages, settings, and API integration.
 * Using constants ensures consistency and easier maintenance across the codebase.
 *
 * @package    ai-tool-center
 * @subpackage Aitoce/constants
 * @author     sjvision <contact@ai-tool-center.com>
 */

// Prevent direct access to this file.
if (!defined('WPINC')) {
    die;
}

/**
 * Account levels and admin menu slugs.
 * These constants are used to identify user account levels and main menu items.
 */

// Account levels (Free, Basic, Advanced)
if (!defined('AITOCE_ACCOUNT_LEVELS')) {
    define('AITOCE_ACCOUNT_LEVELS', ['Free', 'Basic', 'Advanced']);
}

// NimBot Defaults (Free, Basic, Advanced)
if (!defined('AITOCE_NIMBOT_DEFAULTS')) {
    define('AITOCE_NIMBOT_DEFAULTS', [
        AITOCE_ACCOUNT_LEVELS[0] => [
            'popup' => [
                'history' => 1,
                'transcript' => 12
            ],
            'page' => [
                'history' => 1,
                'transcript' => 12
            ],
        ],
        AITOCE_ACCOUNT_LEVELS[1] => [
            'popup' => [
                'history' => 5,
                'transcript' => 24
            ],
            'page' => [
                'history' => 5,
                'transcript' => 12
            ],
        ],
        AITOCE_ACCOUNT_LEVELS[2] => [
            'popup' => [
                'history' => 50,
                'transcript' => 72
            ],
            'page' => [
                'history' => 50,
                'transcript' => 12
            ],
        ],
    ]);
}

// OpenAI Models
if (!defined('AITOCE_OPENAI_MODELS')) {
    define('AITOCE_OPENAI_MODELS', [
        'gpt-4.1' => [
            'name' => 'GPT-4.1',
            'url' => 'v1/chat/completions'
        ], 
        'gpt-4.1-mini' => [
            'name' => 'GPT-4.1 mini',
            'url' => 'v1/chat/completions'
        ], 
        'gpt-4.1-nano' => [
            'name' => 'GPT-4.1 nano',
            'url' => 'v1/chat/completions'
        ], 
        'o4-mini' => [
            'name' => 'o4-mini',
            'url' => 'v1/chat/completions'
        ], 
        'o3-mini' => [
            'name' => 'o3-mini',
            'url' => 'v1/chat/completions'
        ],
    ]);
}



// Main admin menu slug
if (!defined('AITOCE_MENU_SLUG')) {
    define('AITOCE_MENU_SLUG', 'ai-tool-center');
}

/**
 * Account Tab Settings
 * Constants for the Account settings page and its fields.
 */
if (!defined('AITOCE_MENU_SLUG_ACCOUNT')) {
    define('AITOCE_MENU_SLUG_ACCOUNT', 'ai-tool-center');
}
if (!defined('AITOCE_OPTION_SLUG_ACCOUNT2')) {
    define('AITOCE_OPTION_SLUG_ACCOUNT2', 'aitoce-account-settings');
}
if (!defined('AITOCE_OPTION_NAME_ACCOUNT')) {
    define('AITOCE_OPTION_NAME_ACCOUNT', 'aitoce_account');
}
if (!defined('AITOCE_OPTION_SECTION_ACCOUNT2')) {
    define('AITOCE_OPTION_SECTION_ACCOUNT2', 'aitoce_account_section');
}

/**
 * Model Tab Settings
 * Constants for the Model settings page and its fields.
 */
if (!defined('AITOCE_MENU_SLUG_MODEL')) {
    define('AITOCE_MENU_SLUG_MODEL', 'aitoce-model');
}

// Define Pre Set LLM's
if (!defined('AITOCE_OPTION_SLUG_MODEL_OPENAI')) {
    define('AITOCE_OPTION_SLUG_MODEL_OPENAI', 'aitoce-model-openai-settings');
}
if (!defined('AITOCE_OPTION_NAME_MODEL_OPENAI')) {
    define('AITOCE_OPTION_NAME_MODEL_OPENAI', 'aitoce_model_openai');
}
if (!defined('AITOCE_OPTION_SECTION_MODEL_OPENAI')) {
    define('AITOCE_OPTION_SECTION_MODEL_OPENAI', 'aitoce_model_openai_section');
}

// Custom LLM
if (!defined('AITOCE_OPTION_SLUG_MODEL_CUSTOM')) {
    define('AITOCE_OPTION_SLUG_MODEL_CUSTOM', 'aitoce-model-custom-settings');
}
if (!defined('AITOCE_OPTION_NAME_MODEL_CUSTOM')) {
    define('AITOCE_OPTION_NAME_MODEL_CUSTOM', 'aitoce_model_custom');
}
if (!defined('AITOCE_OPTION_SECTION_MODEL_CUSTOM')) {
    define('AITOCE_OPTION_SECTION_MODEL_CUSTOM', 'aitoce_model_custom_section');
}

/**
 * PopUp Tab Settings
 * Constants for the PopUp settings page and its fields.
 */
if (!defined('AITOCE_MENU_SLUG_POPUP')) {
    define('AITOCE_MENU_SLUG_POPUP', 'aitoce-popup');
}
if (!defined('AITOCE_OPTION_SLUG_POPUP')) {
    define('AITOCE_OPTION_SLUG_POPUP', 'aitoce-popup-settings');
}
if (!defined('AITOCE_OPTION_NAME_POPUP')) {
    define('AITOCE_OPTION_NAME_POPUP', 'aitoce_popup');
}
if (!defined('AITOCE_OPTION_SECTION_POPUP')) {
    define('AITOCE_OPTION_SECTION_POPUP', 'aitoce_popup_section');
}

/**
 * Page Tab Settings
 * Constants for the Page settings page and its fields.
 */
if (!defined('AITOCE_MENU_SLUG_PAGE')) {
    define('AITOCE_MENU_SLUG_PAGE', 'aitoce-page');
}
if (!defined('AITOCE_OPTION_SLUG_PAGE')) {
    define('AITOCE_OPTION_SLUG_PAGE', 'aitoce-page-settings');
}
if (!defined('AITOCE_OPTION_NAME_PAGE')) {
    define('AITOCE_OPTION_NAME_PAGE', 'aitoce_page');
}
if (!defined('AITOCE_OPTION_SECTION_PAGE')) {
    define('AITOCE_OPTION_SECTION_PAGE', 'aitoce_page_section');
}

/**
 * Settings Tab Settings
 * Constants for the settings settings page and its fields.
 */
if (!defined('AITOCE_MENU_SLUG_SETTINGS')) {
    define('AITOCE_MENU_SLUG_SETTINGS', 'aitoce-settings');
}
if (!defined('AITOCE_OPTION_SLUG_SETTINGS')) {
    define('AITOCE_OPTION_SLUG_SETTINGS', 'aitoce-settings-settings');
}
if (!defined('AITOCE_OPTION_NAME_SETTINGS')) {
    define('AITOCE_OPTION_NAME_SETTINGS', 'aitoce_settings');
}
if (!defined('AITOCE_OPTION_SECTION_SETTINGS')) {
    define('AITOCE_OPTION_SECTION_SETTINGS', 'aitoce_settings_section');
}